Rename certificates.{cc,h} -> certificate.{cc,h}.
[libdcp.git] / src / dcp.h
index 450a3c00a4b72db6d39a8f6a0c62bd15c8fc0c88..44fe7621ed38e6b95041528d665c6818f7ae64d2 100644 (file)
--- a/src/dcp.h
+++ b/src/dcp.h
@@ -25,7 +25,7 @@
 #define LIBDCP_DCP_H
 
 #include "types.h"
-#include "certificates.h"
+#include "certificate.h"
 #include "metadata.h"
 #include <boost/shared_ptr.hpp>
 #include <boost/signals2.hpp>
@@ -41,34 +41,38 @@ namespace xmlpp {
 namespace dcp
 {
 
-class Content; 
+class Content;
 class Reel;
 class CPL;
 class XMLMetadata;
 class Signer;
 class DecryptedKDM;
 class Asset;
-
-namespace parse {
-       class AssetMap;
-}
+class DCPReadError;
 
 /** @class DCP
  *  @brief A class to create or read a DCP.
  */
-       
+
 class DCP : public boost::noncopyable
 {
 public:
        /** Construct a DCP.  You can pass an existing DCP's directory
-        *  as the parameter, or a non-existant folder to create a new
-        *  DCP in.
+        *  as the parameter; alternatively, directory will be created
+        *  if it does not exist.  Note that if you pass an existing DCP
+        *  into this constructor it will not be read until you call ::read().
         *
         *  @param directory Directory containing the DCP's files.
         */
        DCP (boost::filesystem::path directory);
 
-       void read ();
+       typedef std::list<boost::shared_ptr<DCPReadError> > ReadErrors;
+
+       /** Read the DCP's structure into this object.
+        *  @param keep_going true to try to keep going in the face of (some) errors.
+        *  @param errors List of errors that will be added to if keep_going is true.
+        */
+       void read (bool keep_going = false, ReadErrors* errors = 0);
 
        /** Compare this DCP with another, according to various options.
         *  @param other DCP to compare this one to.
@@ -76,16 +80,12 @@ public:
         *  @param note Functor to handle notes made by the equality operation.
         *  @return true if the DCPs are equal according to EqualityOptions, otherwise false.
         */
-       bool equals (DCP const & other, EqualityOptions options, boost::function<void (NoteType, std::string)> note) const;
+       bool equals (DCP const & other, EqualityOptions options, NoteHandler note) const;
 
-       void add (boost::shared_ptr<Asset> asset);
+       void add (boost::shared_ptr<CPL> cpl);
 
        std::list<boost::shared_ptr<CPL> > cpls () const;
-
-       /** @return All this DCP's assets (note that CPLs are assets) */
-       std::list<boost::shared_ptr<Asset> > assets () const {
-               return _assets;
-       }
+       std::list<boost::shared_ptr<Asset> > assets () const;
 
        bool encrypted () const;
 
@@ -108,7 +108,7 @@ private:
                XMLMetadata metadata,
                boost::shared_ptr<const Signer> signer
                ) const;
-       
+
        void write_volindex (Standard standard) const;
 
        /** Write the ASSETMAP file.
@@ -119,8 +119,8 @@ private:
 
        /** the directory that we are writing to */
        boost::filesystem::path _directory;
-       /** the assets that make up this DCP */
-       std::list<boost::shared_ptr<Asset> > _assets;
+       /** the CPLs that make up this DCP */
+       std::list<boost::shared_ptr<CPL> > _cpls;
 };
 
 }